import { Filters } from '../types/search';
import { ListWithTotalCount, ServiceResponse } from '../types/service';
import { FetchService, FetchServiceResponse, TransformResponseData } from './fetchService';
/**
 * Specifies Options used to configure RestService
 */
export interface RestServiceOptions {
    /**
     * Enable logging.
     */
    enableLog: boolean;
    /**
     * Specifies url page query parameter name used within getList method. If not specified paging is not applied
     * or it's provided through filters.
     */
    pageParamName?: string;
    /**
     * Specifies url rows per page query parameter name used within getList method.
     */
    rowsPerPageParamName?: string;
    /**
     * Callback method to override default build query function (called internally by getList).
     */
    buildQuery?: (filters: Filters, page?: number, rowsPerPage?: number) => string;
    /**
     * Callback method to override default buid paging query (called internally by buildQuery)
     */
    buildPagingQuery?: (page?: number, rowsPerPage?: number) => string;
}
/**
 * There is nothing specific about REST here. However it is named REST because implements some common logic
 * for accessing our 'standard' REST API serevices: e.g., implementation for HTTP method calls using FetchService,
 * paging with 'page-size' and 'page-number' query parameters, filtering using query parameters, response and error handling.
 *
 * While RestService covers some range of scenarios it is highly customizaed to specific API signature.
 * Therefore, RestServiceOptions could be used for further customization.
 */
export declare class RestService {
    fetchService: FetchService;
    options: RestServiceOptions;
    constructor(options: RestServiceOptions | undefined, fetchService: FetchService);
    buildPageQuery: (page?: number | undefined, rowsPerPage?: number | undefined) => string;
    buildSearchQuery: (filters: Filters, page?: number | undefined, rowsPerPage?: number | undefined) => string;
    handleResponse: (response?: FetchServiceResponse | undefined) => ServiceResponse<any>;
    handleError: (error: any) => ServiceResponse<undefined>;
    getList: (url: string, filters: Filters, page?: number | undefined, rowsPerPage?: number | undefined, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<ListWithTotalCount<any> | undefined>>;
    get: (url: string, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any | undefined>>;
    /**
     * Calls FetchService.post method, handles response and errros.
     * @param url Url to POST to.
     * @param data
     * @param init
     * @param transformResponseData
     * @returns
     */
    post: (url: string, data: any, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any>>;
    modify: (url: string, data: any, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any>>;
    replace: (url: string, data: any, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any>>;
    delete: (url: string, data?: any, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any>>;
    postFormData: (url: string, formData: FormData, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any>>;
    modifyFormData: (url: string, formData: FormData, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any>>;
    replaceFormData: (url: string, formData: FormData, init?: ResponseInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<ServiceResponse<any>>;
    log: (message?: any, ...optionalParameters: any[]) => void;
}
